"""
	Licensed Materials - Property of IBM Corp. 
IBM Rational Build Forge 
(c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.   

U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by 
GSA ADP Schedule Contract with IBM Corp. 

	
	File name: Logger.py
	
	Logger used by Jython scripts in the framework
"""

############## CLASS :: _Logger ##########################
# A simple log configuration handler which works like    #
# the JDK Logger Configuration                           #
##########################################################

import java
import os
import sys
from    java.util import Properties
from    java.io import FileInputStream
from types import *

import Globals

class _LogConfig:
	def __init__(self):
		
		rafwHome = Globals.getInstallRoot()
		
		self.LOG_CONSTANTS = {}
		self.LOG_CONSTANTS['ERROR'] = 5
		self.LOG_CONSTANTS['WARN'] = 4
		self.LOG_CONSTANTS['INFO'] = 3
		self.LOG_CONSTANTS['DEBUG'] = 2
		self.LOG_CONSTANTS['TRACE'] = 1
		
		self.logConfig = self.loadLogConfig(rafwHome + "/logging.properties")
		
	#endDef
	
	############ loadLogConfig( path ) ####################
	# Reads in the logging configuration file and returns # 
	# it as a dict                                        #
	#######################################################
	def loadLogConfig(self, path):
		properties=Properties();
		try:
			properties.load(FileInputStream(path))
		except:
			print "Cannot read property file %s" % (path)
			defaultDict = {}
			defaultDict['.level'] = 'TRACE'
			return defaultDict
		#endTry
	
		thisDict = {}
		propEnum = properties.propertyNames()
		while (propEnum.hasMoreElements()):
			key = propEnum.nextElement()
			thisDict[key] = properties.getProperty(key)
		#endWhile
		return thisDict
	#endDef
	
	def getLogLevel(self, scriptName):
		if (self.logConfig.has_key(scriptName + '.level')):
			logConfigName = self.logConfig[scriptName + '.level']
			logLevel = self.LOG_CONSTANTS[logConfigName]
		else:
			logConfigName = self.logConfig['.level']
			logLevel = self.LOG_CONSTANTS[logConfigName]
		#endIf
		#print "logLevel for: " + scriptName + " is: " + str(logLevel)
		return logLevel
	#endDef
	
#endClass

#global singleton logging configuration
LogConfig = _LogConfig()

############## CLASS :: _Logger ##########################
# A simple logger                                        #
#                                                        #
##########################################################
class _Logger:
	
	def __init__(self, scriptName):
		self.scriptName = scriptName 
		self.logLevel = LogConfig.getLogLevel(self.scriptName)
	#endDef

	############## traceEnter  ##############################
	#   Description:                                        #
	#    Used to denote entering a method                   #
	#      Lists the method name and the parameters         #
	#                                                       #
	#   Inputs:                                             #
	#                                                       #
	#########################################################
	def traceEnter(self, args = None):
		if (self.logLevel <= LogConfig.LOG_CONSTANTS['TRACE']):
			print self.scriptName + " > " + self.getCaller() + ": " + self._getAsString(args)
		#endIf
	#endDef
	
	def traceExit(self, retVal = None):
		if (self.logLevel <= LogConfig.LOG_CONSTANTS['TRACE']):
			print self.scriptName + " < " + self.getCaller() + ": " + self._getAsString(retVal)
		#endIf
	#endDef
	
	def trace(self, message):
		if (self.logLevel <= LogConfig.LOG_CONSTANTS['TRACE']):
			print self.scriptName + " - " + self.getCaller() + ": " + str(message)
		#endIf
	#endDef
	
	def isTraceEnabled(self):
		return (self.logLevel <= LogConfig.LOG_CONSTANTS['TRACE'])
	#endDef
	
	def debug(self, message):
		if (self.logLevel <= LogConfig.LOG_CONSTANTS['DEBUG']):
			print self.scriptName + " - " + self.getCaller() + ": " + str(message)
		#endIf
	#endDef
	
	def isDebugEnabled(self):
		return (self.logLevel <= LogConfig.LOG_CONSTANTS['DEBUG'])
	#endDef
	
	def info(self, message):
		if (self.logLevel <= LogConfig.LOG_CONSTANTS['INFO']):
			print self.scriptName + " - " + self.getCaller() + ": " + str(message)
		#endIf
	#endDef
	
	def isInfoEnabled(self):
		return (self.logLevel <= LogConfig.LOG_CONSTANTS['INFO'])
	#endDef
	
	def warn(self, message):
		if (self.logLevel <= LogConfig.LOG_CONSTANTS['WARN']):
			print self.scriptName + " - " + self.getCaller() + ": " + str(message)
		#endIf
	#endDef
	
	def isWarnEnabled(self):
		return (self.logLevel <= LogConfig.LOG_CONSTANTS['WARN'])
	#endDef
	
	def error(self, message):
		if (self.logLevel <= LogConfig.LOG_CONSTANTS['ERROR']):
			print self.scriptName + " - " + self.getCaller() + ": " + str(message)
		#endIf
	#endDef
	
	def isErrorEnabled(self):
		return (self.logLevel <= LogConfig.LOG_CONSTANTS['ERROR'])
	#endDef
	
	def getCaller(self):
		return sys._getframe(2).f_code.co_name
	#endDef
	
	def _getAsString(self, args):
		t = type(args)
		if t == TupleType or t == ListType:
			argsAsString = ""
			for arg in args:
				if (len(argsAsString) > 0):
					argsAsString += ", "
				#endIf
				argsAsString += str(arg)
			#endFor
			return "[" + argsAsString + "]"
		else:
			return str(args)
		#endIf
	#endDef
	
#endClass

